#
# spec file for package python3-pycurl
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-pycurl
Version:        7.19.5.1
Release:        4.2
Summary:        PycURL -- cURL library module
License:        LGPL-2.1+ and MIT
Group:          Development/Languages/Python
Url:            http://pycurl.sourceforge.net/
Source:         https://pypi.python.org/packages/source/p/pycurl/pycurl-%{version}.tar.gz
# PATCH-FIX-UPSTREAM remove __DATE__ and __TIME__
Patch0:         pycurl-7.19.5-no-runtime-curlvercheck.patch
BuildRequires:  libcurl-devel >= 7.19.0
BuildRequires:  openssl-devel
BuildRequires:  python3-2to3
BuildRequires:  python3-bottle
BuildRequires:  python3-devel
BuildRequires:  python3-nose
BuildRequires:  python3-simplejson
Requires:       python3-bottle
Requires:       python3-simplejson
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This module provides bindings for the cURL library.

%package doc
Summary:        Documentation for python-curl
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}

%description doc
This module provides bindings for the cURL library.

This package contains documentation and examples.

%prep
%setup -q -n pycurl-%{version}
%patch0 -p1

%build
2to3 -w --no-diffs -n .
CFLAGS="%{optflags}" python3 setup.py build --with-ssl

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot} --with-ssl
rm -rf %{buildroot}%{_datadir}/doc # Remove wrongly installed junk

%files
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog COPYING-LGPL COPYING-MIT README.rst
%{python3_sitearch}/*

%files doc
%defattr(-,root,root)
%doc examples doc/*.rst

%changelog
* Sun Jan 25 2015 arun@gmx.de
- specfile: update copyright year
- update to version 7.19.5.1:
  * This release primarily fixes build breakage against libcurl 7.19.4
    through 7.21.1, such as versions shipped with CentOS.
* Sat Aug  2 2014 i@marguerite.su
- update version 7.19.5
  * Documentation greatly improved. Quickstart guide added.
  * pycurl.Curl, pycurl.CurlMulti and pycurl.CurlShare are now classes
    rather than factory functions. Previously, the classes were "hidden"
    (they were accessible as e.g. type(pycurl.Curl()), but could not be
    instantiated, nor could class methods be obtained from the classes.
    Please see this mailing list post for further information:
    http://curl.haxx.se/mail/curlpython-2014-06/0004.html
  * When passing a file-like object to READDATA option, PycURL was
    mistakenly looking for write method on this object. Now read method
    is looked up, as would be expected.
  * Python 3.4 is now officially supported.
  * CherryPy is no longer required for the test suite, ssl module from
    the Python standard library is used instead.
  * Fixed a reference leak of SOCKET and TIMER callbacks on
    CurlMulti instances, thanks to Ben Darnell.
  * Added CURLOPT_SSH_KNOWNHOSTS (libcurl 7.19.6+).
  * Added CURLE_FTP_ACCEPT_FAILED (libcurl 7.24.0+).
  * Added CURLE_NOT_BUILT_IN and CURLE_UNKNOWN_OPTION (libcurl 7.21.5+).
  * Added CURL_SEEKFUNC_OK, CURL_SEEKFUNC_FAIL and
    CURL_SEEKFUNC_CANTSEEK. All contstants require libcurl 7.19.5+;
    numeric values of CURL_SEEKFUNC_OK and CURL_SEEKFUNC_FAIL were
    understood earlier but constants only exist as of libcurl 7.19.5.
  * Added CURLINFO_CONDITION_UNMET (libcurl 7.19.4+).
  * Added CURLPROXY_HTTP_1_0 (libcurl 7.19.4+).
  * Added CURLOPT_SOCKS5_GSSAPI_SERVICE and
    CURLOPT_SOCKS5_GSSAPI_NEC (libcurl 7.19.4+).
  * Added CURLOPT_TFTP_BLKSIZE (libcurl 7.19.4+).
  * Added CURLOPT_PROTOCOLS, CURLOPT_REDIR_PROTOCOLS and associated
    CURLPROTO_* constants, which require libcurl 7.19.4+.
  * Fixed a reference leak of OPENSOCKET and SEEK callbacks, thanks to
    Ben Darnell.
  * C source is now split into several files.
  * Documentation is now processed by sphinx.
- removed BuildRequires: python3-CherryPy, no long needed by testsuites
- refreshed patch pycurl-7.19.5-no-runtime-curlvercheck.patch
  * upstream split C source into several files, now we need to patch
    module.c
- Deleted patch pycurl-no-runtime-curlvercheck.patch
* Mon May 26 2014 toddrme2178@gmail.com
- Removed part of patch that breaks now necessary things:
  pycurl-no-runtime-curlvercheck.patch
- Specify ssl type since it is not automatically detected.
* Tue May 20 2014 toddrme2178@gmail.com
- Update to version 7.19.3.1
  * Added --avoid-stdio setup.py option to avoid passing FILE
    pointers from Python to libcurl. Applies to Python 2 only.
  * Added CURLMOPT_CHUNK_LENGTH_PENALTY_SIZE,
    CURLMOPT_CONTENT_LENGTH_PENALTY_SIZE, CURLMOPT_MAX_HOST_CONNECTIONS
    CURLMOPT_MAX_PIPELINE_LENGTH, CURLMOPT_MAX_TOTAL_CONNECTIONS
    multi options (patch by Jakob Truelsen).
  * SSL detection logic changed to consult `curl-config --static-libs`
    even if `curl-config --libs` succeeded. This should achieve
    pre-7.19.3 behavior with respect to automatic SSL detection
    (patch by Andjelko Horvat).
- Update to version 7.19.3
  * Added CURLOPT_NOPROXY.
  * Added CURLINFO_LOCAL_PORT, CURLINFO_PRIMARY_PORT and
    CURLINFO_LOCAL_IP (patch by Adam Jacob Muller).
  * When running on Python 2.x, for compatibility with Python 3.x,
    Unicode strings containing ASCII code points only are now accepted
    in setopt() calls.
  * PycURL now requires that compile time SSL backend used by libcurl
    is the same as the one used at runtime. setup.py supports
  - -with-ssl, --with-gnutls and --with-nss options like libcurl does,
    to specify which backend libcurl uses. On some systems PycURL can
    automatically figure out libcurl's backend.
    If the backend is not one for which PycURL provides crypto locks
    (i.e., any of the other backends supported by libcurl),
    no runtime SSL backend check is performed.
  * Default PycURL user agent string is now built at runtime, and will
    include the user agent string of libcurl loaded at runtime rather
    than the one present at compile time.
  * PycURL will now use WSAduplicateSocket rather than dup on Windows
    to duplicate sockets obtained from OPENSOCKETFUNCTION.
    Using dup may have caused crashes, OPENSOCKETFUNCTION should
    now be usable on Windows.
  * A new script, winbuild.py, was added to build PycURL on Windows
    against Python 2.6, 2.7, 3.2 and 3.3.
  * Added CURL_LOCK_DATA_SSL_SESSION (patch by Tom Pierce).
  * Added E_OPERATION_TIMEDOUT (patch by Romuald Brunet).
  * setup.py now handles --help argument and will print PycURL-specific
    configuration options in addition to distutils help.
  * Windows build configuration has been redone:
    PYCURL_USE_LIBCURL_DLL #define is gone, use --use-libcurl-dll
    argument to setup.py to build against a libcurl DLL.
    CURL_STATICLIB is now #defined only when --use-libcurl-dll is not
    given to setup.py, and PycURL is built against libcurl statically.
  - -libcurl-lib-name option can be used to override libcurl import
    library name.
  * Added CURLAUTH_DIGEST_IE as pycurl.HTTPAUTH_DIGEST_IE.
  * Added CURLOPT_POSTREDIR option and CURL_REDIR_POST_301,
    CURL_REDIR_POST_302, CURL_REDIR_POST_303 and CURL_REDIR_POST_ALL
    constants. CURL_REDIR_POST_303 requires libcurl 7.26.0 or higher,
    all others require libcurl 7.19.1 or higher.
  * PycURL now supports Python 3.1 through 3.3. Python 3.0 might
    work but it appears to ship with broken distutils, making virtualenv
    not function on it.
  * PycURL multi objects now have the multi constants defined on them.
    Previously the constants were only available on pycurl module.
    The new behavior matches that of curl and share objects.
  * PycURL share objects can now be closed via the close() method.
  * PycURL will no longer call `curl-config --static-libs` if
    `curl-config --libs` succeeds and returns output.
    Systems on which neither `curl-config --libs` nor
    `curl-config --static-libs` do the right thing should provide
    a `curl-config` wrapper that is sane.
  * Added CURLFORM_BUFFER and CURLFORM_BUFFERPTR.
  * pycurl.version and user agent string now include both
    PycURL version and libcurl version as separate items.
  * Added CURLOPT_DNS_SERVERS.
  * PycURL can now be dynamically linked against libcurl on Windows
    if PYCURL_USE_LIBCURL_DLL is #defined during compilation.
  * Breaking change: opensocket callback now takes an additional
    (address, port) tuple argument. Existing callbacks will need to
    be modified to accept this new argument.
    https://github.com/pycurl/pycurl/pull/18
- Update to version 7.19.0.3
  * Re-release of 7.19.0.2 with minor changes to build Windows packages
    due to botched 7.19.0.2 files on PyPi.
    http://curl.haxx.se/mail/curlpython-2013-12/0021.html
- Update to version 7.19.0.2 [requires libcurl-7.19.0 or better] - 2013-10-08
  * Fixed a bug in a commit made in 2008 but not released until 7.19.0.1
    which caused CURLOPT_POSTFIELDS to not correctly increment reference
    count of the object being given as its argument, despite libcurl not
    copying the data provided by said object.
  * Added support for libcurl pause/unpause functionality,
    via curl_easy_pause call and returning READFUNC_PAUSE from
    read callback function.
- Update to version 7.19.0.1 [requires libcurl-7.19.0 or better] - 2013-09-23
  * Test matrix tool added to test against all supported Python and
    libcurl versions.
  * Python 2.4 is now the minimum required version.
  * Source code, bugs and patches are now kept on GitHub.
  * Added CURLINFO_CERTINFO and CURLOPT_CERTINFO.
  * Added CURLOPT_RESOLVE.
  * PycURL can now be used with Python binaries without thread
    support.
  * gcrypt is no longer initialized when a newer version of gnutls
    is used.
  * Marked NSS as supported.
  * Fixed relative URL request logic.
  * Fixed a memory leak in util_curl_init.
  * Added CURLOPT_USERNAME and CURLOPT_PASSWORD.
  * Fixed handling of big timeout values.
  * Added GLOBAL_ACK_EINTR.
  * setopt(..., None) can be used as unsetopt().
  * CURLOPT_RANGE can now be unset.
  * Write callback can return -1 to signal user abort.
  * Reorganized tests into an automated test suite.
  * Added CURLOPT_SEEKFUNCTION and CURLOPT_SEEKDATA.
  * Cleaned up website.
  * Fix pycurl.reset() (patch by <johansen at sun.com>).
  * Fix install routine in setup.py where
    certain platforms (Solaris, Mac OSX, etc)
    would search for a static copy of libcurl (dbp).
  * Fixed build on OpenSolaris 0906 and other platforms on which
    curl-config does not have a --static-libs option.
  * No longer keep string options copies in the
    Curl Python objects, since string options are
    now managed by libcurl.
- Add additional dependencies
- Remove no longer necessary patches:
  * pycurl-7.18.1-nostaticlibs.patch
  * pycurl-python3.patch
- remove runtime curl version check and __DATE__ __TIME__ usage
  (pycurl-no-runtime-curlvercheck.patch)
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Thu Nov 22 2012 toddrme2178@gmail.com
- Removed openSUSE 11.4 spec file workarounds
* Sat Apr 28 2012 highwaystar.ru@gmail.com
- python3 package created
- added python3 patch from upstream bugtracker
